#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface
from zope.location import ILocation

from onf_website.component.hearing import IHearingInfo
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_skin.interfaces.viewlet import IBreadcrumbs
from pyams_skin.viewlet.breadcrumb import BreadcrumbsAdapter as BaseBreadcrumbsAdapter, BreadcrumbsContentProvider
from pyams_template.template import override_template
from pyams_utils.adapter import adapter_config


@adapter_config(context=(ILocation, IONFBaseLayer, Interface), provides=IBreadcrumbs)
class BreadcrumbsAdapter(BaseBreadcrumbsAdapter):
    """Breadcrumbs adapter

    Use base breadcrumbs adapter, don't use PyAMS custom adapter
    which is using display context as breadcrumbs base.
    """

    @property
    def items(self):
        source = None
        hearing = IHearingInfo(self.context, None)
        if hearing is not None:
            source = hearing.get_source_folder()
            if source is None:
                source = hearing.get_source_site()
        yield from self.get_items(source)


override_template(context=BreadcrumbsContentProvider, layer=IONFBaseLayer,
                  template='breadcrumbs.pt')
